@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2016 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -123,13 +123,19 @@ class BaseFrameContainer extends Core
 			$messageDetail = '';	// 詳細メッセージ
 			
 			// ページID,ページサブIDからアクセス権をチェック
-			$isPublicUrl = $this->gPage->canAccessUrl($isActivePage);
+			$isPublicUrl = $this->gPage->canAccessUrl($isActivePage, $errCode);
 			if (!$isPublicUrl && !$isSystemManageUser){// システム運用可能ユーザかどうか
 				$canAccess = false;
 				$isErrorAccess = true;		// 不正アクセスかどうか
 				$errMessage = 'ユーザに公開されていないページへのアクセス。';
 				
-				if (!$isActivePage) $toAdminType = 3;		// 有効なアクセスポイントでない場合は存在しないページとする
+				if (!$isActivePage){
+					if ($errCode == 1){			// ページIDが不正な場合
+						$toAdminType = 4;
+					} else {
+						$toAdminType = 3;		// 有効なアクセスポイント、ページでない場合は存在しないページとする
+					}
+				}
 			}
 
 			// ################### ユーザアクセス制御 ######################
@@ -229,6 +235,10 @@ class BaseFrameContainer extends Core
 							$this->gPage->setSystemHandleMode(10/*サイト非公開中*/);
 						}
 						break;
+					case 4:		// 不正なページIDの指定
+						$messageDetail = '不正なページIDの指定';
+						$this->gPage->setSystemHandleMode(12/*存在しないページ*/);
+						break;
 					default:		// アクセス不可画面へ
 						// システム制御モードに変更
 						$this->gPage->setSystemHandleMode(11/*アクセス不可*/);
@@ -271,12 +281,12 @@ class BaseFrameContainer extends Core
 			if ($isSystemAdmin){
 				// ポジションの表示画面のアクセスは、すべて管理機能URLで受け付ける
 				// ページIDを再設定
-				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_ID);
+/*				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_ID);
 				if (empty($pageId)) $pageId = $this->gEnv->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
 				$this->gEnv->setCurrentPageId($pageId);
 				$pageSubId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_SUB_ID);
 				if (!empty($pageSubId)) $this->gEnv->setCurrentPageSubId($pageSubId);
-				
+			*/
 				$this->gPage->showPosition(1);			// ポジションを表示
 			} else {
 				return;
@@ -287,12 +297,12 @@ class BaseFrameContainer extends Core
 			if ($isSystemAdmin){
 				// ポジションの表示画面のアクセスは、すべて管理機能URLで受け付ける
 				// ページIDを再設定
-				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_ID);
+/*				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_ID);
 				if (empty($pageId)) $pageId = $this->gEnv->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
 				$this->gEnv->setCurrentPageId($pageId);
 				$pageSubId = $request->trimValueOf(M3_REQUEST_PARAM_DEF_PAGE_SUB_ID);
 				if (!empty($pageSubId)) $this->gEnv->setCurrentPageSubId($pageSubId);
-				
+				*/
 				$this->gPage->showPosition(2);			// ウィジェット付きポジションを表示
 			} else {
 				return;
@@ -620,6 +630,8 @@ class BaseFrameContainer extends Core
 	 */
 	function _createPage($request, $curTemplate, $subTemplateId = '')
 	{
+		$defaultIndexFile = 'index.php';			// テンプレートの起動ファイル
+		
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);		// 実行コマンドを取得
 		
 		// カレントのテンプレートIDを設定
@@ -650,7 +662,149 @@ class BaseFrameContainer extends Core
 		// サブクラスの前処理を実行
 		if (method_exists($this, '_preBuffer')) $this->_preBuffer($request);
 	
-		if ($convType >= 1){		// Joomla!v1.5,v2.5テンプレートのとき
+		if ($convType == 100){		// WordPressテンプレートのとき
+			// WordPress用定義値
+			define('WPINC', 'wp-includes');
+			define('ABSPATH', $this->gEnv->getWordpressRootPath() . '/' );
+			define('TEMPLATEPATH', $this->gEnv->getTemplatesPath() . '/' . $curTemplate);
+			define('STYLESHEETPATH', $this->gEnv->getTemplatesPath() . '/' . $curTemplate);		// 子テンプレートを使用している場合は子テンプレートを示す。デフォルトはテンプレートを示す。
+			define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
+			define('WP_LANG_DIR', WP_CONTENT_DIR . '/languages');
+			define('WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins');
+			define('WP_CONTENT_URL', '/wp-content');				// 定義自体は必要であるが使用しないのでダミー値で定義
+			define('WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins');	// 定義自体は必要であるが使用しないのでダミー値で定義
+			
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/load.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/default-constants.php');		// デフォルト値取得
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/plugin.php');
+
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/functions.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/default-filters.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/l10n.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-walker.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-query.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-walker-page.php');
+//			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-walker-nav-menu.php');
+//			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-dependency.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-post.php');			// コンテンツAPIマネージャーからWP_Post型でデータを取得
+
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/query.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/pluggable.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/post.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/user.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/widgets.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/http.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/kses.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/script-loader.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/theme.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/link-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/category-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/post-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/post-thumbnail-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/comment-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/author-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/nav-menu-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/nav-menu.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/general-template.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/cache.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/shortcodes.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/formatting.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/post-formats.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/taxonomy.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/media.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/embed.php');
+//			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/option.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/pomo/translations.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/pomo/mo.php');
+
+			// テンプレート内のファイルを読み込む
+			if ( file_exists(TEMPLATEPATH . '/functions.php')) include(TEMPLATEPATH . '/functions.php');
+		
+			// Magic3用インターフェイス
+			require_once($this->gEnv->getWordpressRootPath() . '/contentApi.php');	// コンテンツ取得API
+			require_once($this->gEnv->getWordpressRootPath() . '/menuApi.php');		// メニュー情報取得API
+			require_once($this->gEnv->getWordpressRootPath() . '/wpInit.php');		// 初期値設定
+			
+
+			// ##### データ初期化 #####
+			wp_initial_constants();			// 定義値取得
+			m3WpInit();						// Magic3用インターフェイス初期化。$GLOBALS['m3WpOptions']を初期化し、get_option()はここから使用可能にする。
+
+			// プラグイン初期化
+			$GLOBALS['wp_plugin_paths'] = array();			// $wp_plugin_pathsは未使用?
+			foreach (wp_get_active_and_valid_plugins() as $plugin) {// プラグインロード
+				wp_register_plugin_realpath($plugin);
+				include_once($plugin);
+			}
+			unset($plugin);
+
+			// WordPressメインオブジェクト作成
+			$GLOBALS['locale'] = $this->gEnv->getCurrentLanguage();
+			$GLOBALS['wp'] = new WP();
+			$GLOBALS['wp_the_query'] = new WP_Query();
+			$GLOBALS['wp_query'] = $GLOBALS['wp_the_query'];
+			$GLOBALS['gContentApi'] = new contentApi();			// Magic3コンテンツAPIオブジェクト
+			$GLOBALS['gMenuApi'] = new menuApi();			// Magic3メニュー情報APIオブジェクト
+			
+			// 初期処理
+			do_action('setup_theme');
+			load_default_textdomain();
+			do_action('after_setup_theme');
+			do_action('wp_loaded');
+			
+			// ##### 起動PHPファイル取得。データ取得用パラメータ設定。#####
+			// URLパラメータからコンテンツ形式を取得し、ページを選択
+			$params = $this->gRequest->getQueryArray();
+			$paramCount = count($params);
+			reset($params);
+			$firstKey = key($params);
+//			$firstValue = $params[$firstKey];
+			
+			$contentType = $GLOBALS['gContentApi']->getContentType();
+			switch ($contentType){
+			case M3_VIEW_TYPE_CONTENT:		// 汎用コンテンツ
+				if ($firstKey == M3_REQUEST_PARAM_CONTENT_ID || $firstKey == M3_REQUEST_PARAM_CONTENT_ID_SHORT){	// コンテンツIDのとき
+					$defaultIndexFile = get_page_template();		// 固定ページテンプレート
+					
+					// コンテンツID設定
+					$firstValue = $this->gRequest->trimValueOf($firstKey);
+					$GLOBALS['gContentApi']->setContentId($firstValue);
+				}
+				break;
+			case M3_VIEW_TYPE_PRODUCT:	// 製品
+				break;
+			case M3_VIEW_TYPE_BBS:	// BBS
+				break;
+			case M3_VIEW_TYPE_BLOG:	// ブログ
+//				if ($firstKey == M3_REQUEST_PARAM_BLOG_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ID_SHORT ||			// ブログIDのとき
+//					$firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT){		// ブログ記事IDのとき
+				if ($firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT){		// ブログ記事IDのとき
+					$defaultIndexFile = get_single_template();		// 記事詳細テンプレート
+					
+					// コンテンツID設定
+					$firstValue = $this->gRequest->trimValueOf($firstKey);
+					$GLOBALS['gContentApi']->setContentId($firstValue);
+				}
+				break;
+			case M3_VIEW_TYPE_WIKI:	// Wiki
+				break;
+			case M3_VIEW_TYPE_USER:	// ユーザ作成コンテンツ
+				break;
+			case M3_VIEW_TYPE_EVENT:	// イベント
+				break;
+			case M3_VIEW_TYPE_PHOTO:	// フォトギャラリー
+				break;
+			default:
+				// コンテンツタイプが設定されていないページに場合は、固定ページ用のテンプレートを使用
+				$defaultIndexFile = get_page_template();		// 固定ページテンプレート
+				break;
+			}
+			
+			// WordPressオブジェクト作成
+			wp();
+		} else if ($convType >= 1){		// Joomla!v1.5,v2.5テンプレートのとき
 			global $mainframe;
 			require_once($this->gEnv->getJoomlaRootPath() . '/mosDef.php');// Joomla定義読み込み
 			require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
@@ -675,8 +829,8 @@ class BaseFrameContainer extends Core
 			// Joomla!v1.5用の設定
 			define('JPATH_BASE', dirname(__FILE__));
 			define('JPATH_SITE', $this->gEnv->getSystemRootPath());
-			define('JPATH_PLUGINS', $gEnvManager->getJoomlaRootPath() . '/class/plugins');			// プラグインパス
-//			define('JPATH_THEMES', $gEnvManager->getTemplatesPath());								// テンプレートパス		## テンプレート内でエラーが発生するのでここでは定義しない(2015/10/13)
+			define('JPATH_PLUGINS', $this->gEnv->getJoomlaRootPath() . '/class/plugins');			// プラグインパス
+//			define('JPATH_THEMES', $this->gEnv->getTemplatesPath());								// テンプレートパス		## テンプレート内でエラーが発生するのでここでは定義しない(2015/10/13)
 			define('DS', DIRECTORY_SEPARATOR);
 			$this->language = $this->gEnv->getCurrentLanguage();
 			$this->template = $curTemplate;
@@ -716,7 +870,8 @@ class BaseFrameContainer extends Core
 
 		// ################### テンプレート読み込み ###################
 		// テンプレートのポジションタグからウィジェットが実行される
-		$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/index.php';
+		//$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/index.php';
+		$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/' . $defaultIndexFile;
 		if (file_exists($templateIndexFile)){
 			require_once($templateIndexFile);
 		} else {		// テンプレートが存在しないとき
