@@ -538,7 +538,7 @@ CREATE TABLE _templates (
     tm_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレートID
     tm_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
-    tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(0=デフォルトテンプレート(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5,10=Bootstrap v3.0,20=jQuery Mobile)
+    tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(0=デフォルトテンプレート(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5,10=Bootstrap v3.0,20=jQuery Mobile,100=WordPress)
     tm_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     tm_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     tm_generator         VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- テンプレート作成アプリケーション(値=artisteer,themler)
@@ -586,7 +586,7 @@ CREATE TABLE _widgets (
     wd_parent_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 親ウィジェットID(ファイル名)
     wd_content_widget_id VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- コンテンツ編集用のウィジェット
     wd_joomla_class      VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- Joomla!テンプレート用のクラス名
-    wd_template_type     TEXT                                         NOT NULL,      -- 標準以外で対応するテンプレートタイプ(「,」区切りで指定。値=bootstrap,jquerymobile)
+    wd_template_type     TEXT                                         NOT NULL,      -- 標準以外で対応するテンプレートタイプ(「,」区切りで指定。値=bootstrap,jquerymobile,wordpress)
     wd_suffix            VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- HTMLタグのクラス名に付けるサフィックス文字列
     wd_params            VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 各種パラメータ
     wd_author            VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 作者名
