@@ -93,12 +93,13 @@ INSERT INTO _page_def
 (pd_id,   pd_sub_id, pd_position_id, pd_index, pd_widget_id,         pd_config_id, pd_config_name,       pd_menu_id,  pd_title_visible, pd_update_dt) VALUES
 ('index', '',        'user3',        2,        'default_menu',       1,            'メインメニュー設定', 'main_menu', false,             now()),
 ('index', '',        'left',         2,        'wiki_update',        0,            '',                   '',          true,             now()),
-('index', '',        'left',         4,        'default_login_box',   0,            '',                   '',         true,             now()),
+('index', '',        'left',         4,        'wiki_simple',        1,            '名称未設定1',        '',          true,             now()),
+('index', '',        'left',         6,        'default_login_box',   0,            '',                   '',         true,             now()),
 ('index', '',        'footer',       2,       'default_footer',      0,            '',                   '',          false,        now()),
 ('index', '',        'footer',       10,       'gotop',              0,            '',                   '',          false,        now()),
 ('index', 'content', 'main',         6,        'default_content',    0,            '',                   '',          false,            now()),
 ('index', 'wiki',    'main',         5,        'wiki_main',          0,            '',                   '',          false,            now()),
-('index', 'search',  'main',         5,        'custom_search',      1,            '',                   '',          false,            now()),
+('index', 'search',  'main',         5,        'custom_search',      1,            '名称未設定1',                   '',          false,            now()),
 ('index', 'contact', 'main',         5,        'contactus',          0,            '',                   '',          false,            now());
 
 -- 新メニュー対応
@@ -118,6 +119,10 @@ DELETE FROM _widget_param WHERE wp_id = 'custom_search';
 INSERT INTO _widget_param
 (wp_id,          wp_config_id, wp_param,                                                                                                wp_create_dt) VALUES 
 ('custom_search', 1,            'O:8:"stdClass":15:{s:4:"name";s:16:"名称未設定1";s:11:"resultCount";s:2:"20";s:14:"searchTemplate";s:241:"<input id="custom_search_1_text" maxlength="40" size="10" type="text" /> <input class="button" id="custom_search_1_button" type="button" value="検索" /> <input class="button" id="custom_search_1_reset" type="button" value="リセット" />";s:12:"searchTextId";s:20:"custom_search_1_text";s:14:"searchButtonId";s:22:"custom_search_1_button";s:13:"searchResetId";s:21:"custom_search_1_reset";s:15:"isTargetContent";i:1;s:12:"isTargetUser";i:1;s:12:"isTargetBlog";i:1;s:9:"fieldInfo";a:0:{}s:15:"isTargetProduct";i:0;s:13:"isTargetEvent";i:0;s:11:"isTargetBbs";i:0;s:13:"isTargetPhoto";i:0;s:12:"isTargetWiki";i:1;}', now());
+DELETE FROM _widget_param WHERE wp_id = 'wiki_simple';
+INSERT INTO _widget_param
+(wp_id,          wp_config_id, wp_param,                                                                                                wp_create_dt) VALUES 
+('wiki_simple', 1,            'O:8:\"stdClass\":3:{s:2:\"id\";N;s:4:\"name\";s:16:\"名称未設定1\";s:4:\"text\";s:88:\"Pukiwiki記法で作成できます。\r\n-サンプル１\r\n-サンプル2\r\n-サンプル3\";}', now());
 
 -- コンテンツ
 TRUNCATE TABLE content;
