@@ -26,14 +26,15 @@ class elFinderConnector {
 	 * @var string
 	 **/
 	protected $header = 'Content-Type: application/json';
-	
-	
-	/**
-	 * Constructor
-	 *
-	 * @return void
-	 * @author Dmitry (dio) Levashov
-	 **/
+
+
+    /**
+     * Constructor
+     *
+     * @param $elFinder
+     * @param bool $debug
+     * @author Dmitry (dio) Levashov
+     */
 	public function __construct($elFinder, $debug=false) {
 		
 		$this->elFinder = $elFinder;
@@ -56,7 +57,16 @@ class elFinderConnector {
 			$parts = explode('&', $rawPostData);
 			foreach($parts as $part) {
 				list($key, $value) = array_pad(explode('=', $part), 2, '');
-				$src[$key] = rawurldecode($value);
+				$key = rawurldecode($key);
+				if (substr($key, -2) === '[]') {
+					$key = substr($key, 0, strlen($key) - 2);
+					if (!isset($src[$key])) {
+						$src[$key] = array();
+					}
+					$src[$key][] = rawurldecode($value);
+				} else {
+					$src[$key] = rawurldecode($value);
+				}
 			}
 			$_POST = $this->input_filter($src);
 			$_REQUEST = $this->input_filter(array_merge_recursive($src, $_REQUEST));
@@ -84,23 +94,35 @@ class elFinderConnector {
 		}
 		
 		// collect required arguments to exec command
+		$hasFiles = false;
 		foreach ($this->elFinder->commandArgsList($cmd) as $name => $req) {
-			$arg = $name == 'FILES' 
-				? $_FILES 
-				: (isset($src[$name]) ? $src[$name] : '');
-				
-			if (!is_array($arg)) {
-				$arg = trim($arg);
+			if ($name === 'FILES') {
+				if (isset($_FILES)) {
+					$hasFiles = true;
+				} elseif ($req) {
+					$this->output(array('error' => $this->elFinder->error(elFinder::ERROR_INV_PARAMS, $cmd)));
+				}
+			} else {
+				$arg = isset($src[$name])? $src[$name] : '';
+			
+				if (!is_array($arg) && $req !== '') {
+					$arg = trim($arg);
+				}
+				if ($req && $arg === '') {
+					$this->output(array('error' => $this->elFinder->error(elFinder::ERROR_INV_PARAMS, $cmd)));
+				}
+				$args[$name] = $arg;
 			}
-			if ($req && (!isset($arg) || $arg === '')) {
-				$this->output(array('error' => $this->elFinder->error(elFinder::ERROR_INV_PARAMS, $cmd)));
-			}
-			$args[$name] = $arg;
 		}
 		
 		$args['debug'] = isset($src['debug']) ? !!$src['debug'] : false;
 		
-		$this->output($this->elFinder->exec($cmd, $this->input_filter($args)));
+		$args = $this->input_filter($args);
+		if ($hasFiles) {
+			$args['FILES'] = $_FILES;
+		}
+		
+		$this->output($this->elFinder->exec($cmd, $args));
 	}
 	
 	/**
@@ -111,6 +133,9 @@ class elFinderConnector {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function output(array $data) {
+		// clear output buffer
+		while(ob_get_level() && ob_end_clean()){}
+		
 		$header = isset($data['header']) ? $data['header'] : $this->header;
 		unset($data['header']);
 		if ($header) {
@@ -124,18 +149,80 @@ class elFinderConnector {
 		}
 		
 		if (isset($data['pointer'])) {
-			rewind($data['pointer']);
-			fpassthru($data['pointer']);
+			$toEnd = true;
+			$fp = $data['pointer'];
+			if (elFinder::isSeekableStream($fp) && (array_search('Accept-Ranges: none', headers_list()) === false)) {
+				header('Accept-Ranges: bytes');
+				$psize = null;
+				if (!empty($_SERVER['HTTP_RANGE'])) {
+					$size = $data['info']['size'];
+					$start = 0;
+					$end = $size - 1;
+					if (preg_match('/bytes=(\d*)-(\d*)(,?)/i', $_SERVER['HTTP_RANGE'], $matches)) {
+						if (empty($matches[3])) {
+							if (empty($matches[1]) && $matches[1] !== '0') {
+								$start = $size - $matches[2];
+							} else {
+								$start = intval($matches[1]);
+								if (!empty($matches[2])) {
+									$end = intval($matches[2]);
+									if ($end >= $size) {
+										$end = $size - 1;
+									}
+									$toEnd = ($end == ($size - 1));
+								}
+							}
+							$psize = $end - $start + 1;
+							
+							header('HTTP/1.1 206 Partial Content');
+							header('Content-Length: ' . $psize);
+							header('Content-Range: bytes ' . $start . '-' . $end . '/' . $size);
+							
+							fseek($fp, $start);
+						}
+					}
+				}
+				if (is_null($psize)){
+					elFinder::rewind($fp);
+				}
+			} else {
+				header('Accept-Ranges: none');
+				if (isset($data['info']) && ! $data['info']['size']) {
+					if (function_exists('header_remove')) {
+						header_remove('Content-Length');
+					} else {
+						header('Content-Length:');
+					}
+				}
+			}
+
+			// unlock session data for multiple access
+			$this->elFinder->getSession()->close();
+			// client disconnect should abort
+			ignore_user_abort(false);
+
+			if ($toEnd) {
+				fpassthru($fp);
+			} else {
+				$out = fopen('php://output', 'wb');
+				stream_copy_to_stream($fp, $out, $psize);
+				fclose($out);
+			}
 			if (!empty($data['volume'])) {
 				$data['volume']->close($data['pointer'], $data['info']['hash']);
 			}
 			exit();
 		} else {
 			if (!empty($data['raw']) && !empty($data['error'])) {
-				exit($data['error']);
+				echo $data['error'];
 			} else {
-				exit(json_encode($data));
+				if (isset($data['debug']) && isset($data['debug']['phpErrors'])) {
+					$data['debug']['phpErrors'] = array_merge($data['debug']['phpErrors'], elFinder::$phpErrors);
+				}
+				echo json_encode($data);
 			}
+			flush();
+			exit(0);
 		}
 		
 	}
@@ -147,7 +234,7 @@ class elFinderConnector {
 	 * @return mixed
 	 * @author Naoki Sawada
 	 */
-	private function input_filter($args) {
+	protected function input_filter($args) {
 		static $magic_quotes_gpc = NULL;
 		
 		if ($magic_quotes_gpc === NULL)
